@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
 """
 Command line action to launch the project watcher
-
-TODO: Watcher could bug in case of an unbuilded project in some 
-      cases (like in DEBUG=False), this has to be verified
 """
 import os, time
 
@@ -13,8 +10,8 @@ from argh import arg
 
 from optimus.logs import init_logging
 
-@arg('--settings', default='settings', help='Python path to the settings module')
-@arg('--loglevel', default='info', choices=['debug','info','warning','error','critical'], help='The minimal verbosity level to limit logs output')
+@arg('-s', '--settings', default='settings', help='Python path to the settings module')
+@arg('-l', '--loglevel', default='info', choices=['debug','info','warning','error','critical'], help='The minimal verbosity level to limit logs output')
 @arg('--logfile', default=None, help='A filepath that if setted, will be used to save logs output')
 @arg('--silent', default=False, help="If setted, logs output won't be printed out")
 def watch(args):
@@ -41,7 +38,12 @@ def watch(args):
     # Init environments
     assets_env = register_assets()
     pages_env = PageBuilder(assets_env=assets_env)
-    # TODO: add a first build to avoid error on unbuilded project ?
+    
+    # add a first build to avoid error on unbuilded project
+    if not os.path.exists(settings.PUBLISH_DIR):
+        root_logger.info('Seems you never do a first build so do it now')
+        pages_env.build_bulk(settings.PAGES)
+    
     pages_env.scan_bulk(settings.PAGES)
     
     observer = Observer()
@@ -53,7 +55,7 @@ def watch(args):
         'ignore_directories': False,
         'case_sensitive': False,
     }
-    watcher_templates_patterns.update(getattr(settings, 'WATCHER_TEMPLATES_PATTERNS', {}))
+    watcher_templates_patterns.update(settings.WATCHER_TEMPLATES_PATTERNS)
     # Assets watcher settings
     watcher_assets_patterns = {
         'patterns': ['*.css', '*.js', '*.json'],
@@ -61,7 +63,7 @@ def watch(args):
         'ignore_directories': False,
         'case_sensitive': False,
     }
-    watcher_assets_patterns.update(getattr(settings, 'WATCHER_ASSETS_PATTERNS', {}))
+    watcher_assets_patterns.update(settings.WATCHER_ASSETS_PATTERNS)
     
     # Init templates and assets event watchers
     templates_event_handler = TemplatesWatchEventHandler(settings, root_logger, assets_env, pages_env, **watcher_templates_patterns)
@@ -71,6 +73,8 @@ def watch(args):
     observer.schedule(templates_event_handler, settings.TEMPLATES_DIR, recursive=True)
     if assets_env is not None:
         observer.schedule(assets_event_handler, settings.SOURCES_DIR, recursive=True)
+        
+    root_logger.warning('Launching the watcher, use CTRL+C to stop it')
     observer.start()
     try:
         while True:
